@@ -1,10 +1,10 @@
-from dataclasses import dataclass, field, fields, asdict
-from typing import Any, ClassVar, Dict, List, Optional
-from feature import Features
+from dataclasses import dataclass, asdict
+from typing import Any, List, Optional
+from explainaboard.feature import Features
 import json
 import os
-import config
-from utils.logging import get_logger
+from explainaboard import config
+from explainaboard.utils.logging import get_logger
 import dataclasses
 import copy
 
@@ -88,9 +88,9 @@ class SysOutputInfo:
 
     # set in the system_output scripts
     task_name: str
-    model_name: str = None
-    dataset_name: str = None
-    metric_names: List[str] = None
+    model_name: Optional[str] = None
+    dataset_name: Optional[str] = None
+    metric_names: Optional[List[str]] = None
     # language : str = "English"
 
     # set later
@@ -106,11 +106,14 @@ class SysOutputInfo:
         """
         with open(os.path.join(dataset_info_dir, config.SYS_OUTPUT_INFO_FILENAME), "wb") as f:
             self._dump_info(f)
+    
+    def to_dict(self) -> dict:
+        return asdict(self)
 
 
     def _dump_info(self, file):
         """SystemOutputInfo => JSON"""
-        file.write(json.dumps(asdict(self), indent=4).encode("utf-8"))
+        file.write(json.dumps(self.to_dict(), indent=4).encode("utf-8"))
 
 
     @classmethod
@@ -128,11 +131,17 @@ class SysOutputInfo:
             sys_output_info_dict = json.load(f)
         return cls.from_dict(sys_output_info_dict)
 
+    # @classmethod
+    # def from_dict(cls, task_name: str, sys_output_info_dict: dict) -> "SysOutputInfo":
+    #     field_names = set(f.name for f in dataclasses.fields(cls))
+    #     return cls(task_name, **{k: v for k, v in sys_output_info_dict.items() if k in field_names})
+
     @classmethod
     def from_dict(cls, sys_output_info_dict: dict) -> "SysOutputInfo":
         field_names = set(f.name for f in dataclasses.fields(cls))
         return cls(**{k: v for k, v in sys_output_info_dict.items() if k in field_names})
 
+
     def update(self, other_sys_output_info: "SysOutputInfo", ignore_none=True):
         self_dict = self.__dict__
         self_dict.update(
